---
title: "Lecture 00: Template"
description: "A template for scribe notes"
layout: page
---

Scribes:

- Will Rosenbaum 
- Finnegan Zappenbaum (canine)

This page serves as reference and template for your scribe notes. Your notes should be written using github flavored markdown. You can [read about the basic syntax here](https://guides.github.com/features/mastering-markdown/). You can also [download the source code for this template here](). Markdown is a lightweight markup langauge that allows you to produce formatted text from plain text files. Unlike other more complicated markup langauges (like html and LaTeX), the format is easily readable to humans. It is also the standard documentation format for many open-source (and proprietary) projects, such as those hosted on Github. There are many variants of markdown out there, but this document gives an example of most (if not all) of the markdown you'll need to produce your scribe notes.

## Overview

This first section gives an overview of the lecture and lists the major topics covered. 

## Sections, Structure, and Formatting

This is another section. As you can see, it contains some subsections. Section headings begin with two or more number signs: `##`. Use `##` for sections, `###` for subsections, `####` for subsubsections, and so on.

### Formatting Text

To write basic, unformatted text, simply write what you want to say! Use a blank line (i.e., double carriage return) to indicate paragraph breaks.

See, here is another paragraph!

You can also make text *italic* or **boldface**.

### Lists

You can also make ordered an unordered lists. Here's bulleted lists:

- some item
- another item
    + sub-item
	+ another sub-item
- yet another item

And an ordered list:

1. first item
2. second item
3. third item
    + something special about the third item

### Special Formatting: Code and Math

Markdown has special syntax to indicate code and math. You can write inline code expressions by surrounding the code by a single grave accent mark (opening quote). The result looks like this `int a = 10`. For longer code displays, you can make a separate paragraph whose first and last lines are three accent grave marks. You can specify the language (or `text` for plain text) after the marks on the first line. Be sure to **use spaces, not tabs for indentation.** Here is a Java program:

```java
public class HelloWorld{
    public static void main(String[] args) {
        System.out.println("Hello, World!");	
    }
}
```

And here is some plain, unformatted text

```text
initialize sum = 0

for each integer i from 1 to 10:
    if i is odd:
        sum = sum + i
		
print sum
```

To write inline mathematical expressions, you can surround LaTeX math syntax with double dollar signs (`$$...$$`): $$x = 3.14159\ldots$$. In math mode, you can write superscripts and subscripts using `_` and `^`, respectively: $$x_0 = 0$$, $$2^2 = 4$$. If your super/sub-script contains multiple characters, you'll need to surround the script in curly braces. For example `x_12` typesets as $$x_12$$, while `x_{12}` gives $$x_{12}$$. Special symbols can be printed using LaTeX commands. Each command starts with a backslash `\`. For example, Greek letters can be written $$\alpha, \beta, \gamma, \ldots$$. Open and closing curly braces are written `\{` and `\}` respectively (since `{` and `}` are used to group expressions such as subscripts in LaTeX). Thus, $$\{2, 3, 5\}$$ is typeset using `\{2, 3, 5\}`. There are LaTeX commands for most mathematical symbols you can think of; [see here](http://tug.ctan.org/info/undergradmath/undergradmath.pdf) for some of the most-used constructions.

To make a display math equation (i.e., and equation on its own line), you can surround a paragraph with `$$`s:

$$
\sum_{k = 1}^n (2 k - 1) = 1 + 3 + 5 + \cdots + (2 n - 1) = n^2.
$$

## Links and Images

You can form hyperlinks [like this](https://en.wikipedia.org/wiki/Hyperlink). Note that the format is `[link text](https://somewebsite.edu)`. The same syntax can also be used to link to files, such as [`HelloWorld.java`](HelloWorld.java). Just be sure the linked file is in the same directory as your notes. The syntax for including an image is similar--just start with a `!`. The following image was included using `![Finnegan](finnegan.jpg)`:

![Finnegan](finnegan.jpg)

## Previewing Markdown

Most modern IDEs (e.g., IntelliJ Idea) and many text editors (e.g., Visual Studio Code) include markdown preview so you can see how the formatted output of your markdown will look. There are also online tools that allow you to paste in markdown and render a preview, for example [upmath.me](https://upmath.me).

## Conclusion

Hopefully this is enough to get you started. 


